@@ -1,5 +1,5 @@
 class MixinBase:
-    """ Allows you to use any combination of mixin classes which pass unused *args and **kwargs up to their superclass,
+    """Allows you to use any combination of mixin classes which pass unused *args and **kwargs up to their superclass,
     without encountering:
     ```
     Error
@@ -15,8 +15,7 @@ class MixinBase:
     """
 
     def __init__(self, *args, **kwargs):
-        """ Constructor for ResourceBase
-        """
+        """Constructor for ResourceBase"""
         if (len(args) > 0) or (len(kwargs.keys()) > 0):
             raise TypeError("object.__init__() takes no parameters")
         super().__init__()
