@@ -5,15 +5,15 @@ from twined.utils import TwinedEncoder
 
 
 class OctueJSONEncoder(TwinedEncoder):
-    """A JSON Encoder which allows objects having a `serialise()` method to control their own conversion to primitives."""
+    """A JSON Encoder which allows objects having a `to_primitive` method to control their own conversion to primitives."""
 
     def default(self, obj):
 
-        # If the class defines a serialise() method then use it
-        if hasattr(obj, "serialise"):
-            return obj.serialise()
+        # If the class defines a `to_primitive` method, use it.
+        if hasattr(obj, "to_primitive"):
+            return obj.to_primitive()
 
-        # Serialise sets as sorted list (JSON doesn't support sets).
+        # Convert sets to sorted lists (JSON doesn't support sets).
         if isinstance(obj, set):
             return {"_type": "set", "items": sorted(obj)}
 
@@ -23,5 +23,5 @@ class OctueJSONEncoder(TwinedEncoder):
         if isinstance(obj, datetime.datetime):
             return {"_type": "datetime", "value": obj.isoformat()}
 
-        # Otherwise let the base class default method raise the TypeError
+        # Otherwise let the base class default method raise the TypeError.
         return TwinedEncoder.default(self, obj)
